==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/advancements/AlfheimPortalBreadTrigger.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.advancements;

import com.google.gson.JsonObject;

import net.minecraft.advancements.critereon.*;
import net.minecraft.class_195;
import net.minecraft.class_2048;
import net.minecraft.class_2090;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4558;
import net.minecraft.class_5257;
import net.minecraft.class_5267;
import org.jetbrains.annotations.NotNull;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class AlfheimPortalBreadTrigger extends class_4558<AlfheimPortalBreadTrigger.Instance> {
	public static final class_2960 ID = prefix("alf_portal_bread");
	public static final AlfheimPortalBreadTrigger INSTANCE = new AlfheimPortalBreadTrigger();

	private AlfheimPortalBreadTrigger() {}

	@NotNull
	@Override
	public class_2960 method_794() {
		return ID;
	}

	@NotNull
	@Override
	public AlfheimPortalBreadTrigger.Instance method_27854(@NotNull JsonObject json, class_2048.class_5258 playerPredicate, class_5257 conditions) {
		return new AlfheimPortalBreadTrigger.Instance(playerPredicate, class_2090.method_9021(json.get("portal_location")));
	}

	public void trigger(class_3222 player, class_2338 portal) {
		this.method_22510(player, instance -> instance.test(player.method_14220(), portal));
	}

	public static class Instance extends class_195 {
		private final class_2090 portal;

		public Instance(class_2048.class_5258 playerPredicate, class_2090 portal) {
			super(ID, playerPredicate);
			this.portal = portal;
		}

		@NotNull
		@Override
		public class_2960 method_806() {
			return ID;
		}

		boolean test(class_3218 world, class_2338 portal) {
			return this.portal.method_9018(world, portal.method_10263(), portal.method_10264(), portal.method_10260());
		}

		public class_2090 getPortal() {
			return this.portal;
		}

		@Override
		public JsonObject method_807(class_5267 context) {
			JsonObject json = super.method_807(context);
			if (portal != class_2090.field_9685) {
				json.add("portal_location", portal.method_9019());
			}
			return json;
		}
	}
}

==> Botania-1.20.1-451-FABRIC-20260131.092931-41-sources.jar: vazkii/botania/common/advancements/AlfheimPortalBreadTrigger.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.advancements;

import com.google.gson.JsonObject;

import net.minecraft.advancements.critereon.*;
import net.minecraft.class_195;
import net.minecraft.class_2090;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4558;
import net.minecraft.class_5257;
import net.minecraft.class_5258;
import net.minecraft.class_5267;
import org.jetbrains.annotations.NotNull;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

public class AlfheimPortalBreadTrigger extends class_4558<AlfheimPortalBreadTrigger.Instance> {
	public static final class_2960 ID = prefix("alf_portal_bread");
	public static final AlfheimPortalBreadTrigger INSTANCE = new AlfheimPortalBreadTrigger();

	private AlfheimPortalBreadTrigger() {}

	@NotNull
	@Override
	public class_2960 method_794() {
		return ID;
	}

	@NotNull
	@Override
	public AlfheimPortalBreadTrigger.Instance method_27854(@NotNull JsonObject json, class_5258 playerPredicate, class_5257 conditions) {
		return new AlfheimPortalBreadTrigger.Instance(playerPredicate, class_2090.method_9021(json.get("portal_location")));
	}

	public void trigger(class_3222 player, class_2338 portal) {
		this.method_22510(player, instance -> instance.test(player.method_51469(), portal));
	}

	public static class Instance extends class_195 {
		private final class_2090 portal;

		public Instance(class_5258 playerPredicate, class_2090 portal) {
			super(ID, playerPredicate);
			this.portal = portal;
		}

		@NotNull
		@Override
		public class_2960 method_806() {
			return ID;
		}

		boolean test(class_3218 world, class_2338 portal) {
			return this.portal.method_9018(world, portal.method_10263(), portal.method_10264(), portal.method_10260());
		}

		public class_2090 getPortal() {
			return this.portal;
		}

		@Override
		public JsonObject method_807(class_5267 context) {
			JsonObject json = super.method_807(context);
			if (portal != class_2090.field_9685) {
				json.add("portal_location", portal.method_9019());
			}
			return json;
		}
	}
}
